@@ -22,13 +22,15 @@ def _try_decode(bytes_: bytes) -> str:
     try:
         return bytes_.decode("utf-8")
     except UnicodeDecodeError:
-        charset_match = from_bytes(bytes_).best()
-        if charset_match is None:
-            raise CharacterSetDecodeError()
-        try:
-            return bytes_.decode(charset_match.encoding)
-        except UnicodeDecodeError as e:
-            raise CharacterSetDecodeError() from e
+        pass
+
+    charset_match = from_bytes(bytes_).best()
+    if charset_match is None:
+        raise CharacterSetDecodeError()
+    try:
+        return bytes_.decode(charset_match.encoding)
+    except UnicodeDecodeError as e:
+        raise CharacterSetDecodeError() from e
 
 
 def run(cmd: str, env: Mapping[str, str] | None = None) -> Command:
