@@ -33,7 +33,7 @@ class CommitArgs(TypedDict, total=False):
     dry_run: bool
     edit: bool
     extra_cli_args: str
-    message_length_limit: int
+    message_length_limit: int | None
     no_retry: bool
     signoff: bool
     write_message_to_file: Path | None
@@ -48,47 +48,53 @@ class Commit:
             raise NotAGitProjectError()
 
         self.config: BaseConfig = config
-        self.encoding = config.settings["encoding"]
         self.cz = factory.committer_factory(self.config)
         self.arguments = arguments
-        self.temp_file: str = get_backup_file_path()
+        self.backup_file_path = get_backup_file_path()
 
     def _read_backup_message(self) -> str | None:
         # Check the commit backup file exists
-        if not os.path.isfile(self.temp_file):
+        if not self.backup_file_path.is_file():
             return None
 
         # Read commit message from backup
-        with open(self.temp_file, encoding=self.encoding) as f:
+        with open(
+            self.backup_file_path, encoding=self.config.settings["encoding"]
+        ) as f:
             return f.read().strip()
 
-    def _prompt_commit_questions(self) -> str:
+    def _get_message_by_prompt_commit_questions(self) -> str:
         # Prompt user for the commit message
-        cz = self.cz
-        questions = cz.questions()
+        questions = self.cz.questions()
         for question in (q for q in questions if q["type"] == "list"):
             question["use_shortcuts"] = self.config.settings["use_shortcuts"]
         try:
-            answers = questionary.prompt(questions, style=cz.style)
+            answers = questionary.prompt(questions, style=self.cz.style)
         except ValueError as err:
             root_err = err.__context__
             if isinstance(root_err, CzException):
-                raise CustomError(root_err.__str__())
+                raise CustomError(str(root_err))
             raise err
 
         if not answers:
             raise NoAnswersError()
 
-        message = cz.message(answers)
-        message_len = len(message.partition("\n")[0].strip())
-        message_length_limit = self.arguments.get("message_length_limit", 0)
-        if 0 < message_length_limit < message_len:
-            raise CommitMessageLengthExceededError(
-                f"Length of commit message exceeds limit ({message_len}/{message_length_limit})"
-            )
+        message = self.cz.message(answers)
+        if limit := self.arguments.get(
+            "message_length_limit", self.config.settings.get("message_length_limit", 0)
+        ):
+            self._validate_subject_length(message=message, length_limit=limit)
 
         return message
 
+    def _validate_subject_length(self, *, message: str, length_limit: int) -> None:
+        # By the contract, message_length_limit is set to 0 for no limit
+        subject = message.partition("\n")[0].strip()
+        if len(subject) > length_limit:
+            raise CommitMessageLengthExceededError(
+                f"Length of commit message exceeds limit ({len(subject)}/{length_limit}), subject: '{subject}'"
+            )
+
     def manual_edit(self, message: str) -> str:
         editor = git.get_core_editor()
         if editor is None:
@@ -108,16 +114,18 @@ class Commit:
 
     def _get_message(self) -> str:
         if self.arguments.get("retry"):
-            m = self._read_backup_message()
-            if m is None:
+            commit_message = self._read_backup_message()
+            if commit_message is None:
                 raise NoCommitBackupError()
-            return m
+            return commit_message
 
-        if self.config.settings.get("retry_after_failure") and not self.arguments.get(
-            "no_retry"
+        if (
+            self.config.settings.get("retry_after_failure")
+            and not self.arguments.get("no_retry")
+            and (backup_message := self._read_backup_message())
         ):
-            return self._read_backup_message() or self._prompt_commit_questions()
-        return self._prompt_commit_questions()
+            return backup_message
+        return self._get_message_by_prompt_commit_questions()
 
     def __call__(self) -> None:
         extra_args = self.arguments.get("extra_cli_args", "")
@@ -139,15 +147,17 @@ class Commit:
         if write_message_to_file is not None and write_message_to_file.is_dir():
             raise NotAllowed(f"{write_message_to_file} is a directory")
 
-        m = self._get_message()
+        commit_message = self._get_message()
         if self.arguments.get("edit"):
-            m = self.manual_edit(m)
+            commit_message = self.manual_edit(commit_message)
 
-        out.info(f"\n{m}\n")
+        out.info(f"\n{commit_message}\n")
 
         if write_message_to_file:
-            with smart_open(write_message_to_file, "w", encoding=self.encoding) as file:
-                file.write(m)
+            with smart_open(
+                write_message_to_file, "w", encoding=self.config.settings["encoding"]
+            ) as file:
+                file.write(commit_message)
 
         if dry_run:
             raise DryRunExit()
@@ -155,13 +165,15 @@ class Commit:
         if self.config.settings["always_signoff"] or signoff:
             extra_args = f"{extra_args} -s".strip()
 
-        c = git.commit(m, args=extra_args)
+        c = git.commit(commit_message, args=extra_args)
         if c.return_code != 0:
             out.error(c.err)
 
             # Create commit backup
-            with smart_open(self.temp_file, "w", encoding=self.encoding) as f:
-                f.write(m)
+            with smart_open(
+                self.backup_file_path, "w", encoding=self.config.settings["encoding"]
+            ) as f:
+                f.write(commit_message)
 
             raise CommitError()
 
@@ -170,7 +182,7 @@ class Commit:
             return
 
         with contextlib.suppress(FileNotFoundError):
-            os.remove(self.temp_file)
+            self.backup_file_path.unlink()
         out.write(c.err)
         out.write(c.out)
         out.success("Commit successful!")
