@@ -46,6 +46,7 @@ class Settings(TypedDict, total=False):
     ignored_tag_formats: Sequence[str]
     legacy_tag_formats: Sequence[str]
     major_version_zero: bool
+    message_length_limit: int | None
     name: str
     post_bump_hooks: list[str] | None
     pre_bump_hooks: list[str] | None
@@ -61,6 +62,7 @@ class Settings(TypedDict, total=False):
     version_scheme: str | None
     version_type: str | None
     version: str | None
+    breaking_change_exclamation_in_title: bool
 
 
 CONFIG_FILES: list[str] = [
@@ -92,6 +94,7 @@ DEFAULT_SETTINGS: Settings = {
         "Pull request",
         "fixup!",
         "squash!",
+        "amend!",
     ],
     "changelog_file": "CHANGELOG.md",
     "changelog_format": None,  # default guessed from changelog_file
@@ -108,6 +111,8 @@ DEFAULT_SETTINGS: Settings = {
     "always_signoff": False,
     "template": None,  # default provided by plugin
     "extras": {},
+    "breaking_change_exclamation_in_title": False,
+    "message_length_limit": None,  # None for no limit
 }
 
 MAJOR = "MAJOR"
