@@ -177,7 +177,7 @@ class SemverCommitizen(BaseCommitizen):
         "patch": "Bugs",
     }
 
-    def questions(self) -> list:
+    def questions(self) -> list[CzQuestion]:
         return [
             {
                 "type": "list",
@@ -215,6 +215,18 @@ class SemverCommitizen(BaseCommitizen):
         subject = answers.get("subject", "default message").trim()
         return f"{prefix}: {subject}"
 
+    def example(self) -> str:
+        return ""
+
+    def schema(self) -> str:
+        return ""
+
+    def schema_pattern(self) -> str:
+        return ""
+
+    def info(self) -> str:
+        return ""
+
 
 @pytest.fixture()
 def use_cz_semver(mocker):
@@ -229,6 +241,18 @@ class MockPlugin(BaseCommitizen):
     def message(self, answers: Mapping) -> str:
         return ""
 
+    def example(self) -> str:
+        return ""
+
+    def schema(self) -> str:
+        return ""
+
+    def schema_pattern(self) -> str:
+        return ""
+
+    def info(self) -> str:
+        return ""
+
 
 @pytest.fixture
 def mock_plugin(mocker: MockerFixture, config: BaseConfig) -> BaseCommitizen:
